@@ -134,15 +134,16 @@ class LiteralBlockString(UserString):
 class LiteralBlock(_ConcreteQuestionBase):
     """LiteralBlock Node"""
 
-    __slots__ = ("_answer",)
+    __slots__ = ("_answer", 'comment')
 
-    def __init__(self, name, qform):
+    def __init__(self, name, comment, qform):
         #
         _ConcreteQuestionBase.__init__(self, name)
         # register self
         qform.literals[name] = self
         #
         self._answer = LiteralBlockString(None)
+        self.comment = comment
         #
 
     @property
@@ -459,18 +460,11 @@ def block_not_set(block_name, keys):
     return txt + "\n"
 
 
-class ColtErrorAnswerNotDefined(Exception):
+class ColtErrorAnswerNotDefined(SystemExit):
     """Error if answer is not defined"""
 
     def __init__(self, msg):
-        super().__init__()
-        self.msg = msg
-
-    def __repr__(self):
-        return f"ColtErrorAnswerNotDefined:\n{self.msg}"
-
-    def __str__(self):
-        return f"ColtErrorAnswerNotDefined:\n{self.msg}"
+        super().__init__(f"ColtErrorAnswerNotDefined:\n{msg}")
 
 
 class AnswerVisitor(QuestionVisitor):
@@ -627,7 +621,7 @@ class QuestionGeneratorVisitor(QuestionASTVisitor):
 
     def visit_literal_block(self, question):
         """block needs to be in a concrete section"""
-        self.concrete[self.qname] = LiteralBlock(self.question_id, self.qform)
+        self.concrete[self.qname] = LiteralBlock(self.question_id, question.comment, self.qform)
 
     def visit_question(self, question):
         """question needs to be in concrete section"""
@@ -662,35 +656,19 @@ class QuestionGeneratorVisitor(QuestionASTVisitor):
         self.blocks = blocks
 
 
-class ErrorSettingAnswerFromFile(Exception):
+class ErrorSettingAnswerFromFile(SystemExit):
     """errors setting answers from file"""
-    __slots__ = ('filename', 'msg')
 
     def __init__(self, filename, msg):
-        super().__init__()
-        self.filename = filename
-        self.msg = msg
-
-    def __repr__(self):
-        return f"ErrorSettingAnswerFromFile: file = '{self.filename}'\n{self.msg}"
-
-    def __str__(self):
-        return f"ErrorSettingAnswerFromFile: file = '{self.filename}'\n{self.msg}"
+        super().__init__(f"ErrorSettingAnswerFromFile: file = '{filename}'\n{msg}")
 
 
-class ErrorSettingAnswerFromDict(Exception):
+
+class ErrorSettingAnswerFromDict(SystemExit):
     """Error when trying to read answers from a dict"""
-    __slots__ = ('msg',)
 
     def __init__(self, msg):
-        super().__init__()
-        self.msg = msg
-
-    def __repr__(self):
-        return f"ErrorSettingAnswerFromDict:\n{self.msg}"
-
-    def __str__(self):
-        return f"ErrorSettingAnswerFromDict:\n{self.msg}"
+        super().__init__(f"ErrorSettingAnswerFromDict:\n{msg}")
 
 
 class QuestionForm(Mapping, Component):
